@@ -334,14 +334,14 @@ def __apply_profiling(df: DataFrame, profiling_s3_bucket, profiling_s3_key, laye
     else:
         profile_js = calculate_profilling(df, layer)
         __save_database_profile(profile_js, layer)
+        save_database_profile_history(profile_js, profiling_s3_bucket)
         profile_js = json.dumps(profile_js)
         s3_client = S3(bucket_name=profiling_s3_bucket)
 
-
         return s3_client.put_object(profile_js, s3_key=profiling_s3_key)
 
 
-def __save_database_profile(profile_js, layer):
+def __save_database_profile(profile_js, layer, spark=None):
     if layer == "bronze":
         table = "cortex.data_governance_quality.bronze_profile"
     elif layer == "silver":
@@ -349,9 +349,12 @@ def __save_database_profile(profile_js, layer):
     else:
         table = "cortex.data_governance_quality.gold_profile"
 
-    fields = profile_js["profilling"]["descriptiveStatistics"]["fields"]
-    df_default = spark.createDataFrame(pd.json_normalize(fields))
-    df_default.write.option("header", "true").format('delta').mode('append').option("mergeSchema","true").saveAsTable(table)
+    if spark is None:
+        spark = get_spark_session("upsert_data")
+
+    profile_js = json.dumps(profile_js["profilling"]["descriptiveStatistics"]["fields"])
+    df = spark.createDataFrame(profile_js)
+    df.write.option("header", "true").format('delta').mode('append').option("mergeSchema", "true").saveAsTable(table)
 
     # if layer == "bronze":
     #     frequent_fields = profile_js["profilling"]["descriptiveStatistics"]["mostFrequentFields"]
@@ -396,16 +399,19 @@ def apply_processing_function(df: DataFrame, func, func_args, func_kwargs):
         )
 
 # função que grava as métricas de qualidade no databricks
-def save_database_profile_history(quality_js, profiling_s3_bucket):
+def save_database_profile_history(quality_js, profiling_s3_bucket, spark=None):
     if profiling_s3_bucket.find("bronze") >= 0:
         table = "cortex.data_governance_quality.bronze_profile_history"
     elif profiling_s3_bucket.find("silver") >= 0:
         table = "cortex.data_governance_quality.silver_profile_history"
     else:
         table = "cortex.data_governance_quality.gold_profile_history"
+
+    if spark is None:
+        spark = get_spark_session("upsert_data")
         
     fields=quality_js["profilling"]["descriptiveStatistics"]["fields"]
-    df = spark.createDataFrame(pd.json_normalize(fields))
+    df = spark.createDataFrame(fields)
     df.write.option("header", "true").format('delta').mode('append').option("mergeSchema", "true").saveAsTable(table)
 
     # if profiling_s3_bucket.find("bronze") >= 0:
